==> haskell-tasty-rerun-1.1.20-37.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-rerun.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-rerun
version:              1.1.20
visibility:           public
id:                   tasty-rerun-1.1.20-DtrYgApFRNsn6rKzpq2kn
key:                  tasty-rerun-1.1.20-DtrYgApFRNsn6rKzpq2kn
license:              BSD-3-Clause
copyright:
    Oliver Charles (c) 2014,
    Andrew Lelechenko (c) 2019

maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-rerun
synopsis:             Rerun only tests which failed in a previous test run
description:
    This ingredient
    for the <https://hackage.haskell.org/package/tasty tasty> testing framework
    allows filtering a test tree depending
    on the outcome of the previous run.
    This may be useful in many scenarios,
    especially when a test suite grows large.

category:             Testing
abi:                  88079185c93b3790ad7564cb55122240
exposed:              True
exposed-modules:      Test.Tasty.Ingredients.Rerun
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-rerun-1.1.20
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-rerun-1.1.20
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-rerun-1.1.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-rerun
hs-libraries:         HStasty-rerun-1.1.20-DtrYgApFRNsn6rKzpq2kn
depends:
    base-4.18.2.1 containers-0.6.7 filepath-1.4.300.1 mtl-2.3.1
    optparse-applicative-0.18.1.0-AbA9pm273O8LTotNJ1t1CE
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 stm-2.5.1.0
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    tasty-1.5.2-K3PchMZYxV2JdxeMIpuhjP transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-rerun/html/tasty-rerun.haddock
haddock-html:         /usr/share/doc/haskell-tasty-rerun/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-rerun-1.1.20-38-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-rerun.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-rerun
version:              1.1.20
visibility:           public
id:                   tasty-rerun-1.1.20-B4h2KC741Qb1L7QYytUVVz
key:                  tasty-rerun-1.1.20-B4h2KC741Qb1L7QYytUVVz
license:              BSD-3-Clause
copyright:
    Oliver Charles (c) 2014,
    Andrew Lelechenko (c) 2019

maintainer:           ollie@ocharles.org.uk
author:               Oliver Charles
homepage:             http://github.com/ocharles/tasty-rerun
synopsis:             Rerun only tests which failed in a previous test run
description:
    This ingredient
    for the <https://hackage.haskell.org/package/tasty tasty> testing framework
    allows filtering a test tree depending
    on the outcome of the previous run.
    This may be useful in many scenarios,
    especially when a test suite grows large.

category:             Testing
abi:                  20efbeb2b672b172f1af5610cef780f3
exposed:              True
exposed-modules:      Test.Tasty.Ingredients.Rerun
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-rerun-1.1.20
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-rerun-1.1.20
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-rerun-1.1.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-rerun
hs-libraries:         HStasty-rerun-1.1.20-B4h2KC741Qb1L7QYytUVVz
depends:
    base-4.18.2.1 containers-0.6.7 filepath-1.4.300.1 mtl-2.3.1
    optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 stm-2.5.1.0
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    tasty-1.5.2-C3yI3pzTEHWEDVqwlNW4dB transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-tasty-rerun/html/tasty-rerun.haddock
haddock-html:         /usr/share/doc/haskell-tasty-rerun/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
